@@ -447,7 +447,7 @@ class SpotifyAPI:
             index = self.__get_index_for_song(additional_info)
             song_uris = f'spotify:track:{self.__song_dict[index]["id"]}'
             for neighbor in self.__get_recommendations('song', additional_info, K)['id']:
-                song_uris += f',spotify:track:{self.__song_dict[neighbor]["id"]}'
+                song_uris += f',spotify:track:{neighbor}'
         elif type in ['medium', 'short']:
             ids = self.__medium_fav['id'] if type == 'medium' else self.__short_fav['id']
             for neighbor in ids:
@@ -484,6 +484,7 @@ class SpotifyAPI:
             elif K < 1:
                 raise ValueError('Value for K must be between 1 and 99')
 
+            self.__song_name = song
             df = self.__get_recommendations('song', song, K)
             playlist_name = f'{song} Related'
             if generate_csv:
@@ -565,6 +566,7 @@ class SpotifyAPI:
         try:
             all_genres = genres[0][:]
         except IndexError:
+            self.__deny_favorites = True
             raise ValueError(
                 'Playlist chosen does not correspond to any of the users favorite songs')
 
@@ -668,6 +670,9 @@ class SpotifyAPI:
         The build_playlist option when set to True will change the user's library
 
         """
+        if self.__deny_favorites:
+            print("The chosen playlist does not contain the user's favorite songs")
+            return
         df = self.__short_fav
         playlist_name = 'Latest Favorites'
         if generate_csv:
@@ -697,6 +702,9 @@ class SpotifyAPI:
         The build_playlist option when set to True will change the user's library
 
         """
+        if self.__deny_favorites:
+            print("The chosen playlist does not contain the user's favorite songs")
+            return
         df = self.__medium_fav
         playlist_name = 'Recent-ish Favorites'
         if generate_csv:
@@ -716,10 +724,13 @@ class SpotifyAPI:
         """
         Automatic creation of both the favorites related recommendations
         """
-        self.__short_fav = self.__get_recommendations(
-            'short',  self.__end_prepared_fav_data('short'))
-        self.__medium_fav = self.__get_recommendations(
-            'medium',  self.__end_prepared_fav_data('medium'))
+        try:
+            self.__short_fav = self.__get_recommendations(
+                'short',  self.__end_prepared_fav_data('short'))
+            self.__medium_fav = self.__get_recommendations(
+                'medium',  self.__end_prepared_fav_data('medium'))
+        except ValueError:
+            return
 
 
 def start_api(user_id, playlist_url=None, playlist_id=None):
